@@ -1,11 +1,10 @@
 """
 Module for uniform treatment of dataclasses and attrs classes.
 """
-from abc import abstractmethod
-from typing import TypeVar, Generic, Mapping, Type
-
 import dataclasses
+from abc import abstractmethod
 from dataclasses import dataclass
+from typing import TypeVar, Generic, Mapping, Type, Union
 
 from datargs.meta import AbstractClassProperty
 
@@ -18,6 +17,13 @@ class DatargsParams:
     sub_commands: dict = dataclasses.field(default_factory=dict)
     name: str = None
 
+    def __post_init__(self, *args, **kwargs):
+        for key, value in (
+            ("required", True),
+            ("dest", "__datargs_dest__"),
+        ):
+            self.sub_commands.setdefault(key, value)
+
 
 class RecordField(Generic[FieldType]):
     """
@@ -25,6 +31,7 @@ class RecordField(Generic[FieldType]):
     """
 
     _field: FieldType
+    NONE = object()
 
     def __init__(self, field):
         self._field = field
@@ -55,13 +62,6 @@ class RecordField(Generic[FieldType]):
     def type(self):
         return self._field.type
 
-    @property
-    def origin(self):
-        try:
-            return self._field.type.__origin__
-        except AttributeError:
-            return None
-
     @property
     def metadata(self):
         return self._field.metadata
@@ -77,7 +77,7 @@ class DataField(RecordField[dataclasses.Field]):
     """
 
     def is_required(self) -> bool:
-        return self._field.default is dataclasses.MISSING
+        return self.default is dataclasses.MISSING
 
 
 class NotARecordClass(Exception):
@@ -178,3 +178,11 @@ except ImportError:
 else:
     # import class to register it in RecordClass._implementors
     import datargs.compat.attrs
+
+
+def is_optional(typ):
+    return (
+        getattr(typ, "__origin__", None) is Union
+        and len(typ.__args__) == 2
+        and type(None) in typ.__args__
+    )
